==> usd-24.03-7-x86_64.pkg.tar.zst: usr/include/pxr/imaging/hd/schemaTypeDefs.h <==
//
// Copyright 2023 Pixar
//
// Licensed under the Apache License, Version 2.0 (the "Apache License")
// with the following modification; you may not use this file except in
// compliance with the Apache License and the following modification to it:
// Section 6. Trademarks. is deleted and replaced with:
//
// 6. Trademarks. This License does not grant permission to use the trade
//    names, trademarks, service marks, or product names of the Licensor
//    and its affiliates, except as required to comply with Section 4(c) of
//    the License and to reproduce the content of the NOTICE file.
//
// You may obtain a copy of the Apache License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the Apache License with the above modification is
// distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied. See the Apache License for the specific
// language governing permissions and limitations under the Apache License.
//
#ifndef PXR_IMAGING_HD_SCHEMA_TYPE_DEFS_H
#define PXR_IMAGING_HD_SCHEMA_TYPE_DEFS_H

#include "pxr/pxr.h"

#include "pxr/imaging/hd/containerSchema.h"
#include "pxr/imaging/hd/dataSourceTypeDefs.h"
#include "pxr/imaging/hd/vectorSchema.h"

PXR_NAMESPACE_OPEN_SCOPE

class HdMaterialConnectionSchema;

// Vectors of numeric types
using HdIntArrayVectorSchema = 
    HdTypedVectorSchema<HdIntArrayDataSource>;

// Vectors of Schemas
using HdRenderProductVectorSchema =
    HdSchemaBasedVectorSchema<class HdRenderProductSchema>;
using HdRenderVarVectorSchema =
    HdSchemaBasedVectorSchema<class HdRenderVarSchema>;
using HdInstanceIndicesVectorSchema =
    HdSchemaBasedVectorSchema<class HdInstanceIndicesSchema>;
using HdMaterialInterfaceMappingVectorSchema =
    HdSchemaBasedVectorSchema<class HdMaterialInterfaceMappingSchema>;
using HdMaterialConnectionVectorSchema =
    HdSchemaBasedVectorSchema<HdMaterialConnectionSchema>;

// Containers of sampled data sources
using HdSampledDataSourceContainerSchema =
    HdTypedContainerSchema<HdSampledDataSource>;

// Containers of schemas
using HdMaterialNodeContainerSchema =
    HdSchemaBasedContainerSchema<class HdMaterialNodeSchema>;
using HdMaterialNodeParameterContainerSchema =
    HdSchemaBasedContainerSchema<class HdMaterialNodeParameterSchema>;
using HdMaterialNetworkContainerSchema =
    HdSchemaBasedContainerSchema<class HdMaterialNetworkSchema>;
using HdMaterialConnectionContainerSchema =
    HdSchemaBasedContainerSchema<HdMaterialConnectionSchema>;

// Containers of vectors of schemas
using HdMaterialConnectionVectorContainerSchema =
    HdSchemaBasedContainerSchema<HdMaterialConnectionVectorSchema>;
using HdMaterialInterfaceMappingsContainerSchema =
    HdSchemaBasedContainerSchema<HdMaterialInterfaceMappingVectorSchema>;

PXR_NAMESPACE_CLOSE_SCOPE

#endif

==> usd-24.08-2-x86_64.pkg.tar.zst: usr/include/pxr/imaging/hd/schemaTypeDefs.h <==
//
// Copyright 2023 Pixar
//
// Licensed under the terms set forth in the LICENSE.txt file available at
// https://openusd.org/license.
//
#ifndef PXR_IMAGING_HD_SCHEMA_TYPE_DEFS_H
#define PXR_IMAGING_HD_SCHEMA_TYPE_DEFS_H

#include "pxr/pxr.h"

#include "pxr/imaging/hd/containerSchema.h"
#include "pxr/imaging/hd/dataSourceTypeDefs.h"
#include "pxr/imaging/hd/vectorSchema.h"

PXR_NAMESPACE_OPEN_SCOPE

class HdMaterialConnectionSchema;

// Vectors of numeric types
using HdIntArrayVectorSchema = 
    HdTypedVectorSchema<HdIntArrayDataSource>;

// Vectors of Schemas
using HdRenderProductVectorSchema =
    HdSchemaBasedVectorSchema<class HdRenderProductSchema>;
using HdRenderVarVectorSchema =
    HdSchemaBasedVectorSchema<class HdRenderVarSchema>;
using HdInstanceIndicesVectorSchema =
    HdSchemaBasedVectorSchema<class HdInstanceIndicesSchema>;
using HdMaterialInterfaceMappingVectorSchema =
    HdSchemaBasedVectorSchema<class HdMaterialInterfaceMappingSchema>;
using HdMaterialConnectionVectorSchema =
    HdSchemaBasedVectorSchema<HdMaterialConnectionSchema>;

// Containers of sampled data sources
using HdSampledDataSourceContainerSchema =
    HdTypedContainerSchema<HdSampledDataSource>;

// Containers of schemas
using HdMaterialNodeContainerSchema =
    HdSchemaBasedContainerSchema<class HdMaterialNodeSchema>;
using HdMaterialNodeParameterContainerSchema =
    HdSchemaBasedContainerSchema<class HdMaterialNodeParameterSchema>;
using HdMaterialNetworkContainerSchema =
    HdSchemaBasedContainerSchema<class HdMaterialNetworkSchema>;
using HdMaterialConnectionContainerSchema =
    HdSchemaBasedContainerSchema<HdMaterialConnectionSchema>;
using HdSampledDataSourceContainerContainerSchema =
    HdSchemaBasedContainerSchema<HdSampledDataSourceContainerSchema>;

// Containers of vectors of schemas
using HdMaterialConnectionVectorContainerSchema =
    HdSchemaBasedContainerSchema<HdMaterialConnectionVectorSchema>;
using HdMaterialInterfaceMappingsContainerSchema =
    HdSchemaBasedContainerSchema<HdMaterialInterfaceMappingVectorSchema>;

PXR_NAMESPACE_CLOSE_SCOPE

#endif
